@@ -13,6 +13,7 @@ mod tests;
 
 
 use core::ptr::{NonNull, slice_from_raw_parts_mut};
+use core::iter::{IntoIterator, FromIterator};
 use core::slice::from_raw_parts_mut;
 use core::mem::{size_of, align_of};
 use core::ops::{Index, IndexMut};
@@ -97,6 +98,38 @@ impl<T> List<T> {
         self.truncate(0);
     }
 
+    /// Creates a new [`List`] with a specified `capacity`, the list will not reallocate until the `capacity` has been met.
+    /// 
+    /// ## Example
+    /// ```rust
+    /// let mut list = List::with_capacity(3);
+    /// 
+    /// list.push(1); list.push(5); list.push(9);
+    /// assert_eq!(list.capacity(), 3);
+    /// 
+    /// list.push(4);
+    /// assert!(list.capcity() > 3);
+    /// ```
+    #[inline]
+    pub fn with_capacity(capacity: usize) -> Self {
+        /* TODO: Allow zero-sized types */
+        assert!(size_of::<T>() > 0, "Zero-sized types are not allowed.");
+        
+        let mut list = Self::new();
+
+        let layout = alloc::Layout::array::<T>(capacity)
+            .expect("Could not allocate memory.");
+        
+        let ptr = NonNull::new(
+            unsafe { alloc::alloc(layout) } as *mut T
+        ).expect("Could not allocate memory");
+
+        list.ptr = ptr;
+        list.capacity = capacity;
+
+        return list;
+    }
+
     /// Appends a new `value` into the [`List`].
     /// 
     /// ## Example
@@ -110,75 +143,68 @@ impl<T> List<T> {
     /// assert_eq!(list, list![1, 2, 3]);
     /// ```
     pub fn push(&mut self, value: T) {
-        assert!(size_of::<T>() > 0, "Zero-sized types are not allowed.");
+        /*
+            TODO:
+            - Cleanup Code
+            - Allow zero-sized types
+        */
         
-        // Initialize allocation
+        assert!(size_of::<T>() > 0, "Zero-sized types are not allowed.");
+
         if self.capacity == 0 {
             let layout = alloc::Layout::array::<T>(INITIAL_CAPACITY)
-                .expect("Could not allocate memory."); // TODO: More verbose panic message.
+                .expect("Could not allocate memory.");
             
-            // SAFETY: Layout is hardcoded to be `INITIAL_CAPACITY * size_of<T>`, and `size_of<T> > 0`.
-            let ptr = unsafe { alloc::alloc(layout) } as *mut T;
+            let ptr = NonNull::new(
+                unsafe { alloc::alloc(layout) } as *mut T
+            ).expect("Could not allocate memory.");
 
-            let ptr = NonNull::new(ptr)
-                .expect("Could not allocate memory."); // TODO: More verbose panic message.
-
-            // SAFETY: `ptr` is non-null and we've allocated enough space for the value.
             unsafe { ptr.as_ptr().write(value); }
             
             self.ptr = ptr;
             self.capacity = INITIAL_CAPACITY;
-            self.len = 1;
         }
 
-        // Push value into allocation
         else if self.len < self.capacity {
             let offset = self.len
                 .checked_mul(size_of::<T>())
-                .expect("Cannot reach memory location."); // TODO: More verbose panic message.
+                .expect("Cannot reach memory location.");
             
-            assert!(offset < isize::MAX as usize, "Wrapped `isize`.");
+            assert!(offset < isize::MAX as usize, "Wrapped `isize`, cannot reach memory location.");
 
-            /*
-                SAFETY:
-                - Offset cannot wrap around
-                - `ptr` is pointing to valid memory
-                - Writing to an offset at `len` is valid
-            */
             unsafe { self.ptr.as_ptr().add(self.len).write(value); }
-
-            self.len += 1;
         }
 
-        // Reallocate & push
         else {
-            debug_assert!(self.len == self.capacity);
-
             let new_capacity = self.capacity.checked_mul(RESIZE_MULTIPLIER)
-                .expect("Capacity wrapped."); // TODO: More verbose panic message.
+                .expect("Capacity wrapped.");
             
-            let new_size = size_of::<T>() * new_capacity;
             let size = size_of::<T>() * self.capacity;
             let align = align_of::<T>();
+            let ptr;
 
             size.checked_add(size % align)
-                .expect("Cannot allocate memory."); // TODO: More verbose panic message.
+                .expect("Cannot reallocate memory.");
     
             unsafe {
                 let layout = alloc::Layout::from_size_align_unchecked(size, align);
 
-                let ptr = alloc::realloc(self.ptr.as_ptr() as *mut u8, layout, new_size);
-
-                let ptr = NonNull::new(ptr as *mut T)
-                    .expect("Could not reallocate."); // TODO: More verbose panic message.
+                ptr = NonNull::new(
+                    alloc::realloc(
+                        self.ptr.as_ptr() as *mut u8,
+                        layout,
+                        size_of::<T>() * new_capacity
+                    ) as *mut T
+                ).expect("Cannot reallocate memory.");
                 
                 ptr.as_ptr().add(self.len).write(value);
-                self.ptr = ptr;
             }
 
-            self.len += 1;
+            self.ptr = ptr;
             self.capacity = new_capacity;
         }
+
+        self.len += 1;
     }
 
     /// Shortens the [`List`], keeping the first `len` items and dropping the rest.
@@ -246,6 +272,54 @@ impl<T> List<T> {
             Some(&mut *self.ptr.as_ptr().add(index))
         };
     }
+
+    /// Returns a reference to the item at the `front` of the list.
+    /// 
+    /// ## Example
+    /// ```rust
+    /// let list = list![2, 4, 6];
+    /// assert_eq!(list.front(), Some(&2));
+    /// ```
+    #[inline]
+    fn front(&self) -> Option<&T> {
+        return self.get(0);
+    }
+
+    /// Returns a reference to the item at the `back` of the list.
+    /// 
+    /// ## Example
+    /// ```rust
+    /// let list = list![2, 4, 6];
+    /// assert_eq!(list.back(), Some(&6));
+    /// ```
+    #[inline]
+    fn back(&self) -> Option<&T> {
+        return self.get(self.len - 1);
+    }
+
+    /// Returns a mutable reference to the item at the `front` of the list.
+    /// 
+    /// ## Example
+    /// ```rust
+    /// let mut list = list![2, 4, 6];
+    /// assert_eq!(list.front_mut(), Some(&mut 2));
+    /// ```
+    #[inline]
+    fn front_mut(&mut self) -> Option<&mut T> {
+        return self.get_mut(0);
+    }
+
+    /// Returns a mutable reference to the item at the `back` of the list.
+    /// 
+    /// ## Example
+    /// ```rust
+    /// let mut list = list![2, 4, 6];
+    /// assert_eq!(list.back_mut(), Some(&mut 6));
+    /// ```
+    #[inline]
+    fn back_mut(&mut self) -> Option<&mut T> {
+        return self.get_mut(self.len - 1);
+    }
 }
 
 
@@ -300,6 +374,24 @@ impl<T: fmt::Debug> fmt::Debug for List<T> {
 }
 
 
+impl<T: fmt::Display> fmt::Display for List<T> {
+    #[inline]
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        if self.len == 0 { return write!(f, "[]"); }
+
+        let mut result = String::from("[");
+
+        for i in 0 .. self.len {
+            result.push_str(
+                format!("{}, ", self[i]).as_str()
+            );
+        }
+
+        return write!(f, "{}", result.strip_suffix(", ").unwrap().to_string() + "]");
+    }
+}
+
+
 impl<T: PartialEq> PartialEq for List<T> {
     #[inline]
     fn eq(&self, other: &Self) -> bool {
@@ -316,4 +408,14 @@ impl<T: PartialEq> PartialEq for List<T> {
 }
 
 
-impl<T: Eq> Eq for List<T> {  }
\ No newline at end of file
+impl<T: Eq> Eq for List<T> {  }
+
+
+impl<T> FromIterator<T> for List<T> {
+    #[inline]
+    fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self {
+        let mut list = List::new();
+        for value in iter { list.push(value); }
+        return list;
+    }
+}
\ No newline at end of file
