@@ -74,4 +74,45 @@ fn eq_ne() {
     assert_eq!(list, list![1, 2, 3, 4, 5]);
     assert_ne!(list, list![0, 1, 2, 3, 4]);
     assert_ne!(list, list![1, 2, 3, 4, 5, 6]);
+}
+
+
+#[test]
+fn display() {
+    let list = list![5, 4, 3, 2, 1];
+
+    assert_eq!(format!("{}", list).as_str(), "[5, 4, 3, 2, 1]");
+}
+
+
+#[test]
+fn front_back() {
+    let mut list = list!["front", "_", "back"];
+
+    *list.front_mut().unwrap() = "FRONT";
+    *list.back_mut().unwrap() = "BACK";
+
+    assert_eq!(list.front(), Some(&"FRONT"));
+    assert_eq!(list.back(), Some(&"BACK"));
+}
+
+
+#[test]
+fn with_capacity() {
+    let mut list = List::with_capacity(3);
+
+    list.push(1); list.push(2); list.push(3);
+    assert_eq!(list.capacity(), 3);
+
+    list.push(4);
+    assert!(list.capacity() > 3);
+}
+
+
+#[test]
+fn from_iter() {
+    let list = [1, 2, 3].iter()
+        .collect::<List<&i32>>();
+    
+    assert_eq!(list, list![&1, &2, &3]);
 }
\ No newline at end of file
