@@ -38,17 +38,6 @@ impl<T> Node<T> {
         };
     }
 
-    /// Converts the [`Node`] into a [`Box`]-ed version of the [`Node`].
-    /// 
-    /// ## Example
-    /// ```rust
-    /// let boxed_node = Node::new(5).into_box();
-    /// assert_eq!(boxed_node, Box::new(Node::new(5)));
-    /// ```
-    pub fn into_box(self) -> Box<Self> {
-        return Box::new(self);
-    }
-
     /// Converts the [`Node`] into a [`Box`], then converts the [`Box`] into a [`NonNull`] of the [`Node`].
     /// 
     /// ## Example
@@ -63,19 +52,29 @@ impl<T> Node<T> {
     /// - Converts the [`Node`] into a [`Box`] before [`NonNull`] conversion, `ptr` should always be valid.
     #[inline]
     pub fn into_non_null(self) -> NonNull<Self> {
-        return unsafe { NonNull::new_unchecked(Box::into_raw(self.into_box())) };
+        return unsafe { NonNull::new_unchecked(Box::into_raw(self.into())) };
     }
 }
 
 
 impl<T: PartialEq> PartialEq for Node<T> {
-    fn eq(&self, other: &Self) -> bool {
-        return self.value == other.value;
+    #[inline]
+    fn eq(&self, rhs: &Self) -> bool {
+        return self.value == rhs.value;
+    }
+}
+
+
+impl<T: PartialEq> PartialEq<T> for Node<T> {
+    #[inline]
+    fn eq(&self, rhs: &T) -> bool {
+        return self.value == *rhs;
     }
 }
 
 
 impl<T: fmt::Debug> fmt::Debug for Node<T> {
+    #[inline]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         return f.debug_struct("Node")
             .field("next", &self.next)
